@@ -1,7 +1,7 @@
 # ABSTRACT: Convenient representation of company from Yandex Maps
 
 package Yandex::Geo::Company;
-$Yandex::Geo::Company::VERSION = '0.06';
+$Yandex::Geo::Company::VERSION = '0.07';
 use strict;
 use warnings;
 
@@ -108,7 +108,7 @@ sub from_json {
 sub to_array {
     my ( $self, $separator ) = @_;
 
-    my $separator = "\n" unless defined $separator;
+    $separator = "\n" unless defined $separator;
     my @res;
 
     for my $p ( @{ properties()->{all} } ) {
@@ -138,7 +138,7 @@ Yandex::Geo::Company - Convenient representation of company from Yandex Maps
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
